==> j2sdk-1_4_2_04-i586-3.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_ko.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_ko extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "\uCDE8\uC18C" },
        { "FileChooser.cancelButtonToolTipText", "\uD30C\uC77C \uC120\uD0DD \uB300\uD654 \uC0C1\uC790\uB97C \uC911\uB2E8\uD569\uB2C8\uB2E4." },
        { "FileChooser.deleteFileButtonText", "\uD30C\uC77C \uC0AD\uC81C" },
        { "FileChooser.filesLabelText", "\uD30C\uC77C" },
        { "FileChooser.foldersLabelText", "\uD3F4\uB354" },
        { "FileChooser.newFolderButtonText", "\uC0C8 \uD3F4\uB354" },
        { "FileChooser.openButtonText", "\uD655\uC778" },
        { "FileChooser.openButtonToolTipText", "\uC120\uD0DD\uD55C \uD30C\uC77C\uC744 \uC5FD\uB2C8\uB2E4." },
        { "FileChooser.openDialogTitleText", "\uC5F4\uAE30" },
        { "FileChooser.pathLabelText", "\uC120\uD0DD:" },
        { "FileChooser.renameFileButtonText", "\uD30C\uC77C \uC774\uB984 \uBC14\uAFB8\uAE30" },
        { "FileChooser.saveButtonText", "\uC800\uC7A5" },
        { "FileChooser.saveButtonToolTipText", "\uC120\uD0DD\uD55C \uD30C\uC77C\uC744 \uC800\uC7A5\uD569\uB2C8\uB2E4." },
        { "FileChooser.saveDialogTitleText", "\uC800\uC7A5" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\uD30C\uB791:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\uC0C9 \uC774\uB984:" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\uB179\uC0C9:" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\uC0C9\uC0C1:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK \uC0C9 \uC120\uD0DD" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "\uBE68\uAC15:" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\uCC44\uB3C4:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\uAC12:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_ko.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_ko extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "\uBAA8\uB4E0 \uD30C\uC77C" },
        { "FileChooser.cancelButtonText", "\uCDE8\uC18C" },
        { "FileChooser.cancelButtonToolTipText", "\uD30C\uC77C \uC120\uD0DD \uB300\uD654 \uC0C1\uC790\uB97C \uC911\uB2E8\uD569\uB2C8\uB2E4." },
        { "FileChooser.deleteFileButtonText", "\uD30C\uC77C \uC0AD\uC81C" },
        { "FileChooser.filesLabelText", "\uD30C\uC77C" },
        { "FileChooser.filterLabelText", "\uD544\uD130:" },
        { "FileChooser.foldersLabelText", "\uD3F4\uB354" },
        { "FileChooser.newFolderButtonText", "\uC0C8 \uD3F4\uB354" },
        { "FileChooser.newFolderDialogText", "\uD3F4\uB354 \uC774\uB984:" },
        { "FileChooser.openButtonText", "\uD655\uC778" },
        { "FileChooser.openButtonToolTipText", "\uC120\uD0DD\uD55C \uD30C\uC77C\uC744 \uC5FD\uB2C8\uB2E4." },
        { "FileChooser.openDialogTitleText", "\uC5F4\uAE30" },
        { "FileChooser.pathLabelText", "\uC120\uD0DD:" },
        { "FileChooser.renameFileButtonText", "\uD30C\uC77C \uC774\uB984 \uBC14\uAFB8\uAE30" },
        { "FileChooser.renameFileDialogText", "\uD30C\uC77C \"{0}\"\uC744 \uB2E4\uC74C\uC73C\uB85C \uC774\uB984 \uBC14\uAFB8\uAE30" },
        { "FileChooser.renameFileErrorText", "\"{0}\"\uC5D0\uC11C \"{1}\"\uB85C \uC774\uB984 \uBC14\uAFB8\uAE30 \uC624\uB958 " },
        { "FileChooser.renameFileErrorTitle", "\uC624\uB958" },
        { "FileChooser.saveButtonText", "\uC800\uC7A5" },
        { "FileChooser.saveButtonToolTipText", "\uC120\uD0DD\uD55C \uD30C\uC77C\uC744 \uC800\uC7A5\uD569\uB2C8\uB2E4." },
        { "FileChooser.saveDialogTitleText", "\uC800\uC7A5" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\uD30C\uB791(B):" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\uC0C9 \uC774\uB984(N):" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\uB179\uC0C9(G):" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\uC0C9\uC0C1(H):" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK \uC0C9 \uC120\uD0DD" },
        { "GTKColorChooserPanel.redMnemonic", "69" },
        { "GTKColorChooserPanel.redText", "\uBE68\uAC15(E):" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\uCC44\uB3C4(S):" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\uAC12(V):" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
